diff --git a/.github/workflows/package_all.yaml b/.github/workflows/package_all.yaml
index e0b2e6714..93522a0b8 100644
--- a/.github/workflows/package_all.yaml
+++ b/.github/workflows/package_all.yaml
@@ -101,7 +101,7 @@ jobs:
       - name: "Build package"
         run: |
           cd release/package
-          ./run.sh package debian-10 --for-docker
+          ./run.sh package debian-11 --for-docker
           ./run.sh docker
       - name: "Upload package"
         uses: actions/upload-artifact@v2
@@ -143,7 +143,7 @@ jobs:
           name: ubuntu-2004
           path: build/output/ubuntu-20.04/memgraph*.deb
 
-  debian-10-platform:
+  debian-11-platform:
     runs-on: [self-hosted, DockerMgBuild]
     timeout-minutes: 60
     steps:
@@ -153,9 +153,9 @@ jobs:
           fetch-depth: 0 # Required because of release/get_version.py
       - name: "Build package"
         run: |
-          ./release/package/run.sh package debian-10 --for-platform
+          ./release/package/run.sh package debian-11 --for-platform
       - name: "Upload package"
         uses: actions/upload-artifact@v2
         with:
-          name: debian-10-platform
-          path: build/output/debian-10/memgraph*.deb
+          name: debian-11-platform
+          path: build/output/debian-11/memgraph*.deb
diff --git a/release/docker/memgraph.dockerfile b/release/docker/memgraph.dockerfile
index f9a12f0df..6aa8ad0ed 100644
--- a/release/docker/memgraph.dockerfile
+++ b/release/docker/memgraph.dockerfile
@@ -1,14 +1,14 @@
-FROM debian:buster
+FROM debian:bullseye
 # NOTE: If you change the base distro update release/package as well.
 
 ARG deb_release
 
 RUN apt-get update && apt-get install -y \
-    openssl libcurl4 libssl1.1 libseccomp2 python3 libpython3.7 python3-pip \
+    openssl libcurl4 libssl1.1 libseccomp2 python3 libpython3.9 python3-pip \
     --no-install-recommends \
   && rm -rf /var/lib/apt/lists/* /tmp/* /var/tmp/*
 
-RUN pip3 install networkx==2.4 numpy==1.19.2 scipy==1.5.2
+RUN pip3 install networkx==2.4 numpy==1.21.4 scipy==1.7.3
 
 COPY ${deb_release} /
 
diff --git a/release/package/run.sh b/release/package/run.sh
index 0809c1517..b8d19797c 100755
--- a/release/package/run.sh
+++ b/release/package/run.sh
@@ -100,8 +100,8 @@ case "$1" in
     ;;
 
     docker)
-        # NOTE: Docker is build on top of Debian 10 package.
-        based_on_os="debian-10"
+        # NOTE: Docker is build on top of Debian 11 package.
+        based_on_os="debian-11"
         # shellcheck disable=SC2012
         last_package_name=$(cd "$HOST_OUTPUT_DIR/$based_on_os" && ls -t memgraph* | head -1)
         docker_build_folder="$PROJECT_ROOT/release/docker"